==> cronapi-java-0.0.100-d-s-sources.jar: Teste.java <==
import com.fasterxml.jackson.annotation.ObjectIdGenerator;
import com.fasterxml.jackson.core.JsonGenerator;
import com.fasterxml.jackson.core.io.SerializedString;
import com.fasterxml.jackson.databind.*;
import com.fasterxml.jackson.databind.cfg.MapperConfig;
import com.fasterxml.jackson.databind.introspect.Annotated;
import com.fasterxml.jackson.databind.introspect.AnnotatedClass;
import com.fasterxml.jackson.databind.introspect.BasicBeanDescription;
import com.fasterxml.jackson.databind.introspect.BeanPropertyDefinition;
import com.fasterxml.jackson.databind.jsontype.NamedType;
import com.fasterxml.jackson.databind.module.SimpleModule;
import com.fasterxml.jackson.databind.ser.BeanPropertyWriter;
import com.fasterxml.jackson.databind.ser.BeanSerializerFactory;
import com.fasterxml.jackson.databind.ser.BeanSerializerModifier;
import com.fasterxml.jackson.databind.ser.VirtualBeanPropertyWriter;
import com.fasterxml.jackson.databind.ser.impl.ObjectIdWriter;
import com.fasterxml.jackson.databind.ser.impl.PropertySerializerMap;
import com.fasterxml.jackson.databind.ser.impl.WritableObjectId;
import com.fasterxml.jackson.databind.ser.std.BeanSerializerBase;
import com.fasterxml.jackson.databind.type.SimpleType;
import com.fasterxml.jackson.databind.util.ClassUtil;
import com.google.gson.Gson;
import com.google.gson.JsonElement;
import com.google.gson.JsonObject;
import cronapi.Pojo;
import cronapi.Var;
import cronapi.clazz.CronapiClassLoader;
import cronapi.serialization.CronappModule;

import java.io.File;
import java.io.IOException;
import java.util.*;

/**
 * Created by thiag_000 on 19/05/2017.
 */
public class Teste {
  public static void main(String[] args) throws Exception {

    System.out.println(Var.valueOf(new File("D:\\conf.xml")).getMD5());
    // Object o = x1.newInstance();
    
  }
}

==> cronapi-java-0.0.129-d-s-sources.jar: Teste.java <==
import com.fasterxml.jackson.annotation.ObjectIdGenerator;
import com.fasterxml.jackson.core.JsonGenerator;
import com.fasterxml.jackson.core.io.SerializedString;
import com.fasterxml.jackson.databind.*;
import com.fasterxml.jackson.databind.cfg.MapperConfig;
import com.fasterxml.jackson.databind.introspect.Annotated;
import com.fasterxml.jackson.databind.introspect.AnnotatedClass;
import com.fasterxml.jackson.databind.introspect.BasicBeanDescription;
import com.fasterxml.jackson.databind.introspect.BeanPropertyDefinition;
import com.fasterxml.jackson.databind.jsontype.NamedType;
import com.fasterxml.jackson.databind.module.SimpleModule;
import com.fasterxml.jackson.databind.ser.BeanPropertyWriter;
import com.fasterxml.jackson.databind.ser.BeanSerializerFactory;
import com.fasterxml.jackson.databind.ser.BeanSerializerModifier;
import com.fasterxml.jackson.databind.ser.VirtualBeanPropertyWriter;
import com.fasterxml.jackson.databind.ser.impl.ObjectIdWriter;
import com.fasterxml.jackson.databind.ser.impl.PropertySerializerMap;
import com.fasterxml.jackson.databind.ser.impl.WritableObjectId;
import com.fasterxml.jackson.databind.ser.std.BeanSerializerBase;
import com.fasterxml.jackson.databind.type.SimpleType;
import com.fasterxml.jackson.databind.util.ClassUtil;
import com.google.gson.Gson;
import com.google.gson.JsonElement;
import com.google.gson.JsonObject;
import cronapi.Pojo;
import cronapi.Var;
import cronapi.clazz.CronapiClassLoader;
import cronapi.io.Operations;
import cronapi.serialization.CronappModule;

import java.io.File;
import java.io.FileInputStream;
import java.io.IOException;
import java.util.*;

/**
 * Created by thiag_000 on 19/05/2017.
 */
public class Teste {
  public static void main(String[] args) throws Exception {

    Map m = new HashMap();
    Map k = new HashMap();
    List x = new ArrayList();
    x.add("qdas");
    m.put("x", "2");

    k.put("ssss", "dasdas");

    m.put("l", k);
    m.put("l1", x);


    FileInputStream stream = new FileInputStream(new File("d:\\teste.json"));

    byte[] xxx = new byte[5];
    //stream.read(xxx);

     Var x1 = cronapi.json.Operations.toJson(Var.valueOf(stream));

    System.out.println(x1);
    // Object o = x1.newInstance();
    
  }
}
